==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitItems.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.entity.monster.EntityFairy;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.item.*;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1826;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public final class InitItems {
    public static void init() {

    }

    public static class_1792 MAID_BACKPACK_SMALL = register("maid_backpack_small", new ItemMaidBackpack());
    public static class_1792 MAID_BACKPACK_MIDDLE = register("maid_backpack_middle", new ItemMaidBackpack());
    public static class_1792 MAID_BACKPACK_BIG = register("maid_backpack_big", new ItemMaidBackpack());
    public static class_1792 CRAFTING_TABLE_BACKPACK = register("crafting_table_backpack", new ItemMaidBackpack());
    public static class_1792 ENDER_CHEST_BACKPACK = register("ender_chest_backpack", new ItemMaidBackpack());
    public static class_1792 FURNACE_BACKPACK = register("furnace_backpack", new ItemMaidBackpack());
    public static class_1792 TANK_BACKPACK = register("tank_backpack", new ItemTankBackpack());
    public static class_1792 CHAIR = register("chair", new ItemChair());
    public static class_1792 HAKUREI_GOHEI = register("hakurei_gohei", new ItemHakureiGohei());
    public static class_1792 SANAE_GOHEI = register("sanae_gohei", new ItemHakureiGohei());
    public static class_1792 MAID_BED = register("maid_bed", new ItemMaidBed());
    public static class_1792 EXTINGUISHER = register("extinguisher", new ItemExtinguisher());
    public static class_1792 ULTRAMARINE_ORB_ELIXIR = register("ultramarine_orb_elixir", new ItemDamageableBauble(6));
    public static class_1792 EXPLOSION_PROTECT_BAUBLE = register("explosion_protect_bauble", new ItemDamageableBauble(32));
    public static class_1792 FIRE_PROTECT_BAUBLE = register("fire_protect_bauble", new ItemDamageableBauble(128));
    public static class_1792 PROJECTILE_PROTECT_BAUBLE = register("projectile_protect_bauble", new ItemDamageableBauble(64));
    public static class_1792 MAGIC_PROTECT_BAUBLE = register("magic_protect_bauble", new ItemDamageableBauble(128));
    public static class_1792 FALL_PROTECT_BAUBLE = register("fall_protect_bauble", new ItemDamageableBauble(32));
    public static class_1792 DROWN_PROTECT_BAUBLE = register("drown_protect_bauble", new ItemDamageableBauble(64));
    public static class_1792 NIMBLE_FABRIC = register("nimble_fabric", new ItemDamageableBauble(64));
    public static class_1792 ITEM_MAGNET_BAUBLE = register("item_magnet_bauble", new ItemNormalBauble());
    public static class_1792 MUTE_BAUBLE = register("mute_bauble", new ItemNormalBauble());
    public static class_1792 ENTITY_PLACEHOLDER = register("entity_placeholder", new ItemEntityPlaceholder());
    public static class_1792 SUBSTITUTE_JIZO = register("substitute_jizo", new ItemSubstituteJizo());
    public static class_1792 POWER_POINT = register("power_point", new ItemPowerPoint());
    public static class_1792 CAMERA = register("camera", new ItemCamera());
    public static class_1792 PHOTO = register("photo", new ItemPhoto());
    public static class_1792 FILM = register("film", new ItemFilm());
    public static class_1792 CHISEL = register("chisel", new ItemChisel());
    public static class_1792 GARAGE_KIT = register("garage_kit", new ItemGarageKit());
    public static class_1792 SMART_SLAB_INIT = register("smart_slab_init", new ItemSmartSlab(ItemSmartSlab.Type.INIT));
    public static class_1792 SMART_SLAB_EMPTY = register("smart_slab_empty", new ItemSmartSlab(ItemSmartSlab.Type.EMPTY));
    public static class_1792 SMART_SLAB_HAS_MAID = register("smart_slab_has_maid", new ItemSmartSlab(ItemSmartSlab.Type.HAS_MAID));
    public static class_1792 TRUMPET = register("trumpet", new ItemTrumpet());
    public static class_1792 WIRELESS_IO = register("wireless_io", new ItemWirelessIO());
    public static class_1792 MAID_BEACON = register("maid_beacon", new ItemMaidBeacon());
    public static class_1792 MODEL_SWITCHER = register("model_switcher", new ItemModelSwitcher());
    public static class_1792 CHAIR_SHOW = register("chair_show", new ItemChairShow());
    public static class_1792 GOMOKU = register("gomoku", new class_1747(InitBlocks.GOMOKU, new class_1792.class_1793()));
    public static class_1792 CCHESS = register("cchess", new class_1747(InitBlocks.CCHESS, new class_1792.class_1793()));
    public static class_1792 WCHESS = register("wchess", new class_1747(InitBlocks.WCHESS, new class_1792.class_1793()));
    public static class_1792 RED_FOX_SCROLL = register("red_fox_scroll", new ItemFoxScroll());
    public static class_1792 WHITE_FOX_SCROLL = register("white_fox_scroll", new ItemFoxScroll());
    public static class_1792 KEYBOARD = register("keyboard", new class_1747(InitBlocks.KEYBOARD, new class_1792.class_1793()));
    public static class_1792 BOOKSHELF = register("bookshelf", new class_1747(InitBlocks.BOOKSHELF, new class_1792.class_1793()));
    public static class_1792 COMPUTER = register("computer", new class_1747(InitBlocks.COMPUTER, new class_1792.class_1793()));
    public static class_1792 FAVORABILITY_TOOL_ADD = register("favorability_tool_add", new ItemFavorabilityTool("add"));
    public static class_1792 FAVORABILITY_TOOL_REDUCE = register("favorability_tool_reduce", new ItemFavorabilityTool("reduce"));
    public static class_1792 FAVORABILITY_TOOL_FULL = register("favorability_tool_full", new ItemFavorabilityTool("full"));
    public static class_1792 SHRINE = register("shrine", new class_1747(InitBlocks.SHRINE, new class_1792.class_1793()));
    public static class_1792 KAPPA_COMPASS = register("kappa_compass", new ItemKappaCompass());
    public static class_1792 BROOM = register("broom", new ItemBroom());
    public static class_1792 PICNIC_BASKET = register("picnic_basket", new ItemPicnicBasket(InitBlocks.PICNIC_MAT));
    public static class_1792 SCARECROW = register("scarecrow", new class_1747(InitBlocks.SCARECROW, new class_1792.class_1793()));
    public static class_1792 SERVANT_BELL = register("servant_bell", new ItemServantBell());
    public static class_1792 ENTITY_ID_COPY = register("entity_id_copy", new ItemEntityIdCopy());
    @SuppressWarnings("deprecation")
    public static class_1792 MONSTER_LIST = register("monster_list", new ItemMonsterList());

    public static class_1792 MAID_SPAWN_EGG = register("maid_spawn_egg", new class_1826(EntityMaid.TYPE, 0xffffff, 0xffffff, new class_1792.class_1793()));
    public static class_1792 FAIRY_SPAWN_EGG = register("fairy_spawn_egg", new class_1826(EntityFairy.TYPE, 0xffffff, 0xffffff, new class_1792.class_1793()));

    public static final class_2960 MEMORIZABLE_GENSOKYO_LOCATION = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "memorizable_gensokyo");

    // 成就图标
    public static class_1792 CHANGE_CHAIR_MODEL = register("change_chair_model", new ItemAdvancementIcon());
    public static class_1792 CHANGE_MAID_MODEL = register("change_maid_model", new ItemAdvancementIcon());
    public static class_1792 MAID_100_HEALTHY = register("maid_100_healthy", new ItemAdvancementIcon());
    public static class_1792 KILL_100 = register("kill_100", new ItemAdvancementIcon());
    public static class_1792 KILL_SLIME_300 = register("kill_slime_300", new ItemAdvancementIcon());
    public static class_1792 ALL_NETHERITE_EQUIPMENT = register("all_netherite_equipment", new ItemAdvancementIcon());
    public static class_1792 KILL_WITHER = register("kill_wither", new ItemAdvancementIcon());
    public static class_1792 KILL_DRAGON = register("kill_dragon", new ItemAdvancementIcon());

    private static class_1792 register(String id, class_1792 item) {
        return class_2378.method_10230(class_7923.field_41178, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), item);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.0-neo1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitItems.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.entity.monster.EntityFairy;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.item.*;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1814;
import net.minecraft.class_1826;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public final class InitItems {
    public static void init() {

    }

    public static class_1792 MAID_BACKPACK_SMALL = register("maid_backpack_small", new ItemMaidBackpack());
    public static class_1792 MAID_BACKPACK_MIDDLE = register("maid_backpack_middle", new ItemMaidBackpack());
    public static class_1792 MAID_BACKPACK_BIG = register("maid_backpack_big", new ItemMaidBackpack());
    public static class_1792 CRAFTING_TABLE_BACKPACK = register("crafting_table_backpack", new ItemMaidBackpack());
    public static class_1792 ENDER_CHEST_BACKPACK = register("ender_chest_backpack", new ItemMaidBackpack());
    public static class_1792 FURNACE_BACKPACK = register("furnace_backpack", new ItemMaidBackpack());
    public static class_1792 TANK_BACKPACK = register("tank_backpack", new ItemTankBackpack());
    public static class_1792 CHAIR = register("chair", new ItemChair());
    public static class_1792 HAKUREI_GOHEI = register("hakurei_gohei", new ItemHakureiGohei());
    public static class_1792 SANAE_GOHEI = register("sanae_gohei", new ItemHakureiGohei());
    public static class_1792 MAID_BED = register("maid_bed", new ItemMaidBed());
    public static class_1792 EXTINGUISHER = register("extinguisher", new ItemExtinguisher());
    public static class_1792 ULTRAMARINE_ORB_ELIXIR = register("ultramarine_orb_elixir", new ItemDamageableBauble(6));
    public static class_1792 EXPLOSION_PROTECT_BAUBLE = register("explosion_protect_bauble", new ItemDamageableBauble(32));
    public static class_1792 FIRE_PROTECT_BAUBLE = register("fire_protect_bauble", new ItemDamageableBauble(128));
    public static class_1792 PROJECTILE_PROTECT_BAUBLE = register("projectile_protect_bauble", new ItemDamageableBauble(64));
    public static class_1792 MAGIC_PROTECT_BAUBLE = register("magic_protect_bauble", new ItemDamageableBauble(128));
    public static class_1792 FALL_PROTECT_BAUBLE = register("fall_protect_bauble", new ItemDamageableBauble(32));
    public static class_1792 DROWN_PROTECT_BAUBLE = register("drown_protect_bauble", new ItemDamageableBauble(64));
    public static class_1792 NIMBLE_FABRIC = register("nimble_fabric", new ItemDamageableBauble(64));
    public static class_1792 ITEM_MAGNET_BAUBLE = register("item_magnet_bauble", new ItemNormalBauble());
    public static class_1792 MUTE_BAUBLE = register("mute_bauble", new ItemNormalBauble());
    public static class_1792 ENTITY_PLACEHOLDER = register("entity_placeholder", new ItemEntityPlaceholder());
    public static class_1792 SUBSTITUTE_JIZO = register("substitute_jizo", new ItemSubstituteJizo());
    public static class_1792 POWER_POINT = register("power_point", new ItemPowerPoint());
    public static class_1792 CAMERA = register("camera", new ItemCamera());
    public static class_1792 PHOTO = register("photo", new ItemPhoto());
    public static class_1792 FILM = register("film", new ItemFilm());
    public static class_1792 CHISEL = register("chisel", new ItemChisel());
    public static class_1792 GARAGE_KIT = register("garage_kit", new ItemGarageKit());
    public static class_1792 SMART_SLAB_INIT = register("smart_slab_init", new ItemSmartSlab(ItemSmartSlab.Type.INIT));
    public static class_1792 SMART_SLAB_EMPTY = register("smart_slab_empty", new ItemSmartSlab(ItemSmartSlab.Type.EMPTY));
    public static class_1792 SMART_SLAB_HAS_MAID = register("smart_slab_has_maid", new ItemSmartSlab(ItemSmartSlab.Type.HAS_MAID));
    public static class_1792 TRUMPET = register("trumpet", new ItemTrumpet());
    public static class_1792 WIRELESS_IO = register("wireless_io", new ItemWirelessIO());
    public static class_1792 MAID_BEACON = register("maid_beacon", new ItemMaidBeacon());
    public static class_1792 MODEL_SWITCHER = register("model_switcher", new ItemModelSwitcher());
    public static class_1792 CHAIR_SHOW = register("chair_show", new ItemChairShow());
    public static class_1792 GOMOKU = register("gomoku", new class_1747(InitBlocks.GOMOKU, new class_1792.class_1793()));
    public static class_1792 CCHESS = register("cchess", new class_1747(InitBlocks.CCHESS, new class_1792.class_1793()));
    public static class_1792 WCHESS = register("wchess", new class_1747(InitBlocks.WCHESS, new class_1792.class_1793()));
    public static class_1792 RED_FOX_SCROLL = register("red_fox_scroll", new ItemFoxScroll());
    public static class_1792 WHITE_FOX_SCROLL = register("white_fox_scroll", new ItemFoxScroll());
    public static class_1792 KEYBOARD = register("keyboard", new class_1747(InitBlocks.KEYBOARD, new class_1792.class_1793()));
    public static class_1792 BOOKSHELF = register("bookshelf", new class_1747(InitBlocks.BOOKSHELF, new class_1792.class_1793()));
    public static class_1792 COMPUTER = register("computer", new class_1747(InitBlocks.COMPUTER, new class_1792.class_1793()));
    public static class_1792 FAVORABILITY_TOOL_ADD = register("favorability_tool_add", new ItemFavorabilityTool("add"));
    public static class_1792 FAVORABILITY_TOOL_REDUCE = register("favorability_tool_reduce", new ItemFavorabilityTool("reduce"));
    public static class_1792 FAVORABILITY_TOOL_FULL = register("favorability_tool_full", new ItemFavorabilityTool("full"));
    public static class_1792 SHRINE = register("shrine", new class_1747(InitBlocks.SHRINE, new class_1792.class_1793().method_7894(class_1814.field_8903)));
    public static class_1792 KAPPA_COMPASS = register("kappa_compass", new ItemKappaCompass());
    public static class_1792 BROOM = register("broom", new ItemBroom());
    public static class_1792 PICNIC_BASKET = register("picnic_basket", new ItemPicnicBasket(InitBlocks.PICNIC_MAT));
    public static class_1792 SCARECROW = register("scarecrow", new class_1747(InitBlocks.SCARECROW, new class_1792.class_1793()));
    public static class_1792 SERVANT_BELL = register("servant_bell", new ItemServantBell());
    public static class_1792 ENTITY_ID_COPY = register("entity_id_copy", new ItemEntityIdCopy());
    public static class_1792 OWNER_CONVERSION_TOOL = register("owner_conversion_tool", new class_1792(new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8904)));
    @SuppressWarnings("deprecation")
    public static class_1792 MONSTER_LIST = register("monster_list", new ItemMonsterList());

    public static class_1792 MAID_SPAWN_EGG = register("maid_spawn_egg", new class_1826(EntityMaid.TYPE, 0xffffff, 0xffffff, new class_1792.class_1793()));
    public static class_1792 FAIRY_SPAWN_EGG = register("fairy_spawn_egg", new class_1826(EntityFairy.TYPE, 0xffffff, 0xffffff, new class_1792.class_1793()));

    public static final class_2960 MEMORIZABLE_GENSOKYO_LOCATION = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "memorizable_gensokyo");

    // 成就图标
    public static class_1792 CHANGE_CHAIR_MODEL = register("change_chair_model", new ItemAdvancementIcon());
    public static class_1792 CHANGE_MAID_MODEL = register("change_maid_model", new ItemAdvancementIcon());
    public static class_1792 MAID_100_HEALTHY = register("maid_100_healthy", new ItemAdvancementIcon());
    public static class_1792 KILL_100 = register("kill_100", new ItemAdvancementIcon());
    public static class_1792 KILL_SLIME_300 = register("kill_slime_300", new ItemAdvancementIcon());
    public static class_1792 ALL_NETHERITE_EQUIPMENT = register("all_netherite_equipment", new ItemAdvancementIcon());
    public static class_1792 KILL_WITHER = register("kill_wither", new ItemAdvancementIcon());
    public static class_1792 KILL_DRAGON = register("kill_dragon", new ItemAdvancementIcon());

    private static class_1792 register(String id, class_1792 item) {
        return class_2378.method_10230(class_7923.field_41178, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), item);
    }
}
